==> meteva-1.3.9-py3-none-any.whl: meteva/product/presentation/t2m_3h_summer_pre.py <==
import datetime
import meteva
import pandas as pd

para_example= {
    "begin_time":datetime.datetime(2020,5,1,8,0),
    "end_time":datetime.datetime(2020,9,30,8,0),
    "station_file":meteva.base.station_国家站,
    "defalut_value":999999,
    "interp": meteva.base.interp_gs_linear,
    "hdf_file_name":"summer.h5",
    "ob_data":{
        "hdf_dir":r"O:\data\hdf\SURFACE\QC_BY_FSOL\TMP_ALL_STATION",
        "dir_ob": r"O:\data\sta\SURFACE\QC_BY_FSOL\TMP_ALL_STATION\YYYYMMDD\YYYYMMDDHH0000.000",
        "hour": None,
        "read_method": meteva.base.io.read_stadata_from_gdsfile,
        "read_para": {},
        "reasonable_value": [0, 1000],
        "operation":None,
        "operation_para":{},
        "time_type": "BT",
    },
    "fo_data":{
        "global": {
            "hdf_dir": r"O:\data\hdf\global_in_china\grid_1w",
            "dir_fo": r"X:\For Verification\GRID_1W\YYYYMMDDHH\tem\YYYYMMDDHH.TTT.h5",
            "read_method": pd.read_hdf,
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 0,
            "time_type": "UT",
        },
        "global_station": {
            "hdf_dir": r"O:\data\hdf\global_in_china\Station_1w",
            "dir_fo": r"X:\For Verification\Station_1w\YYYYMMDDHH\t2m\YYYYMMDDHH.TTT.h5",
            "read_method": pd.read_hdf,
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 0,
            "time_type": "UT",
        },
        "GMOSRR": {
            "hdf_dir": r"O:\data\hdf\GMOSRR\TMP_2M",
            "dir_fo": r"O:\data\grid\GMOSRR\ROLLING_UPDATE\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [3, 24, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        },
        "SCMOC":{
            "hdf_dir": r"O:\data\hdf\NWFD_SCMOC\TMP\2M_ABOVE_GROUND",
            "dir_fo": r"O:\data\grid\NWFD_SCMOC\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para":{},
            "move_fo_time": 0,
            "time_type": "BT",
        },
        "GRAPES": {
            "hdf_dir": r"O:\data\hdf\GRAPES_GFS\TMP\2M_ABOVE_GROUND",
            "dir_fo": r"O:\data\grid\GRAPES_GFS\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        },
        "ECMWF":{
            "hdf_dir": r"O:\data\hdf\ECMWF_HR\TMP_2M",
            "dir_fo": r"O:\data\grid\ECMWF_HR\TMP_2M\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para":{},
            "move_fo_time": 12,
            "time_type": "BT",
        },
        "NWFD_SMERGE": {
            "hdf_dir": r"O:\data\hdf\NWFD_SMERGE\TMP_2M",
            "dir_fo": r"O:\data\grid\NWFD_SMERGE\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        }
    },
    "output_dir":r"O:\data\hdf\combined\temp_2m"
}


if __name__ == '__main__':
    meteva.product.prepare_dataset(para_example)

==> meteva-1.4.0-py3-none-any.whl: meteva/product/presentation/t2m_3h_summer_pre.py <==
import datetime
import meteva
import pandas as pd

para_example= {
    "begin_time":datetime.datetime(2020,8,29,8,0),
    "end_time":datetime.datetime(2020,8,30,8,0),
    "station_file":meteva.base.station_国家站,
    "defalut_value":999999,
    "interp": meteva.base.interp_gs_linear,
    "hdf_file_name":"summer_test1.h5",
    "ob_data":{
        "hdf_dir":r"O:\data\hdf\SURFACE\QC_BY_FSOL\TMP_ALL_STATION",
        "dir_ob": r"O:\data\sta\SURFACE\QC_BY_FSOL\TMP_ALL_STATION\YYYYMMDD\YYYYMMDDHH0000.000",
        "hour": None,
        "read_method": meteva.base.io.read_stadata_from_gdsfile,
        "read_para": {},
        "reasonable_value": [0, 1000],
        "operation":None,
        "operation_para":{},
        "time_type": "BT",
    },
    "fo_data":{
        "DongQuan": {
            "hdf_dir": r"O:\data\hdf\DongQuan\TMP_2M",
            "dir_fo": r"\\10.20.67.214\disaster\newkgyb\ec\objectived\h\YYMMDDHH.TTT",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_stadata_from_micaps3,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        },
        "ECMWF": {
            "hdf_dir": r"O:\data\hdf\ECMWF_HR\TMP_2M",
            "dir_fo": r"O:\data\grid\ECMWF_HR\TMP_2M\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        },
        "GRAPES": {
            "hdf_dir": r"O:\data\hdf\GRAPES_GFS\TMP\2M_ABOVE_GROUND",
            "dir_fo": r"O:\data\grid\GRAPES_GFS\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        },
        "global": {
            "hdf_dir": r"O:\data\hdf\global_in_china\grid_1w",
            "dir_fo": r"X:\For Verification\GRID_1W\YYYYMMDDHH\tem\YYYYMMDDHH.TTT.h5",
            "read_method": pd.read_hdf,
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 0,
            "time_type": "UT",
        },
        "global_station": {
            "hdf_dir": r"O:\data\hdf\global_in_china\Station_1w",
            "dir_fo": r"X:\For Verification\Station_1w\YYYYMMDDHH\t2m\YYYYMMDDHH.TTT.h5",
            "read_method": pd.read_hdf,
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 0,
            "time_type": "UT",
        },
        "GMOSRR": {
            "hdf_dir": r"O:\data\hdf\GMOSRR\TMP_2M",
            "dir_fo": r"O:\data\grid\GMOSRR\ROLLING_UPDATE\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [3, 24, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        },
        "SCMOC": {
            "hdf_dir": r"O:\data\hdf\NWFD_SCMOC\TMP\2M_ABOVE_GROUND",
            "dir_fo": r"O:\data\grid\NWFD_SCMOC\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 0,
            "time_type": "BT",
        },
        "NWFD_SMERGE": {
            "hdf_dir": r"O:\data\hdf\NWFD_SMERGE\TMP_2M",
            "dir_fo": r"O:\data\grid\NWFD_SMERGE\TMP\2M_ABOVE_GROUND\YYYYMMDD\YYMMDDHH.TTT.nc",
            "hour": [8, 20, 12],
            "dtime": [0, 240, 3],
            "read_method": meteva.base.io.read_griddata_from_nc,
            "read_para": {},
            "operation": None,
            "operation_para": {},
            "move_fo_time": 12,
            "time_type": "BT",
        },

    },
    "output_dir":r"O:\data\hdf\combined\temp_2m"
}


if __name__ == '__main__':
    meteva.product.prepare_dataset(para_example)
